<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "V paměti nejsou uloženy úplně všechny kalendáře",
"Everything seems to be completely cached" => "Zdá se, že úplně vše je uloženo v paměti",
"No calendars found." => "Žádné kalendáře nenalezeny.",
"No events found." => "Žádné události nenalezeny.",
"Wrong calendar" => "Nesprávný kalendář",
"You do not have the permissions to edit this event." => "Nemáte práva upravovat tuto událost.",
"The file contained either no events or all events are already saved in your calendar." => "Soubor neobsahoval žádné události, nebo jsou všechny události již ve Vašem kalendáři.",
"events has been saved in the new calendar" => "události byly uloženy v novém kalendáři",
"Import failed" => "Import selhal",
"events has been saved in your calendar" => "událostí bylo uloženo ve Vašem kalendáři",
"New Timezone:" => "Nové časové pásmo:",
"Timezone changed" => "Časové pásmo bylo změněno",
"Invalid request" => "Neplatný požadavek",
"Calendar" => "Kalendář",
"Deletion failed" => "Mazání selhalo.",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "uživatel",
"group" => "skupina",
"Editable" => "Upravitelné",
"Shareable" => "Sdílitelné",
"Deletable" => "Odstranitelné",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "d. MMM[ yyyy]{ '&#8212;' d.[ MMM] yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Neděle",
"Monday" => "Pondělí",
"Tuesday" => "Úterý",
"Wednesday" => "Středa",
"Thursday" => "Čtvrtek",
"Friday" => "Pátek",
"Saturday" => "Sobota",
"Sun." => "Ne",
"Mon." => "Po",
"Tue." => "Út",
"Wed." => "St",
"Thu." => "Čt",
"Fri." => "Pá",
"Sat." => "So",
"January" => "Leden",
"February" => "Únor",
"March" => "Březen",
"April" => "Duben",
"May" => "Květen",
"June" => "Červen",
"July" => "Červenec",
"August" => "Srpen",
"September" => "Září",
"October" => "Říjen",
"November" => "Listopad",
"December" => "Prosinec",
"Jan." => "leden",
"Feb." => "únor",
"Mar." => "březen",
"Apr." => "duben",
"May." => "květen",
"Jun." => "červen",
"Jul." => "červenec",
"Aug." => "srpen",
"Sep." => "září",
"Oct." => "říjen",
"Nov." => "listopad",
"Dec." => "prosinec",
"All day" => "Celý den",
"New Calendar" => "Nový kalendář",
"Missing or invalid fields" => "Chybějící, nebo neplatná pole",
"Title" => "Název",
"From Date" => "Od data",
"From Time" => "Od",
"To Date" => "Do data",
"To Time" => "Do",
"The event ends before it starts" => "Událost končí před svým zahájením",
"There was a database fail" => "Chyba v databázi",
"Birthday" => "Narozeniny",
"Business" => "Obchodní",
"Call" => "Hovor",
"Clients" => "Klienti",
"Deliverer" => "Doručovatel",
"Holidays" => "Prázdniny",
"Ideas" => "Nápady",
"Journey" => "Cesta",
"Jubilee" => "Výročí",
"Meeting" => "Schůzka",
"Other" => "Jiné",
"Personal" => "Osobní",
"Projects" => "Projekty",
"Questions" => "Dotazy",
"Work" => "Práce",
"by" => "od",
"unnamed" => "nepojmenováno",
"You do not have the permissions to update this calendar." => "Nemáte práva pro aktualizaci tohoto kalendáře.",
"You do not have the permissions to delete this calendar." => "Nemáte práva pro smazání tohoto kalendáře.",
"You do not have the permissions to add to this calendar." => "Nemáte práva pro přidání tohoto kalendáře.",
"You do not have the permissions to add events to this calendar." => "Nemáte práva pro přidání událostí do tohoto kalendáře.",
"You do not have the permissions to delete this event." => "Nemáte práva smazat tuto událost.",
"Busy" => "Zaneprázdněná",
"Public" => "Veřejná",
"Private" => "Soukromá",
"Confidential" => "Důvěrná",
"Does not repeat" => "Neopakuje se",
"Daily" => "Denně",
"Weekly" => "Týdně",
"Every Weekday" => "Každý všední den",
"Bi-Weekly" => "Jednou za dva týdny",
"Monthly" => "Měsíčně",
"Yearly" => "Ročně",
"never" => "nikdy",
"by occurrences" => "podle výskytu",
"by date" => "podle data",
"by monthday" => "podle dne v měsíci",
"by weekday" => "podle dne v týdnu",
"events week of month" => "týdenní události v měsíci",
"first" => "první",
"second" => "druhý",
"third" => "třetí",
"fourth" => "čtvrtý",
"fifth" => "pátý",
"last" => "poslední",
"by events date" => "podle data události",
"by yearday(s)" => "po dni (dnech)",
"by weeknumber(s)" => "podle čísel týdnů",
"by day and month" => "podle dne a měsíce",
"Date" => "Datum",
"Cal." => "Kal.",
"Week" => "Týden",
"Month" => "Měsíc",
"List" => "Seznam",
"Today" => "Dnes",
"Settings" => "Nastavení",
"Your calendars" => "Vaše kalendáře",
"CalDav Link" => "Odkaz CalDav",
"Share Calendar" => "Sdílet kalendář",
"Download" => "Stáhnout",
"Edit" => "Upravit",
"Delete" => "Smazat",
"New calendar" => "Nový kalendář",
"Edit calendar" => "Upravit kalendář",
"Displayname" => "Zobrazované jméno",
"Active" => "Aktivní",
"Calendar color" => "Barva kalendáře",
"Save" => "Uložit",
"Submit" => "Odeslat",
"Cancel" => "Zrušit",
"Edit an event" => "Upravit událost",
"Export" => "Exportovat",
"Eventinfo" => "Informace o události",
"Repeating" => "Opakování",
"Alarm" => "Upomínka",
"Attendees" => "Účastníci",
"Share" => "Sdílet",
"Title of the Event" => "Název události",
"Category" => "Kategorie",
"Separate categories with commas" => "Kategorie oddělené čárkami",
"Edit categories" => "Upravit kategorie",
"Access Class" => "Třída přístupu",
"All Day Event" => "Celodenní událost",
"From" => "Od",
"To" => "Do",
"Advanced options" => "Pokročilé možnosti",
"Location" => "Umístění",
"Location of the Event" => "Místo konání události",
"Description" => "Popis",
"Description of the Event" => "Popis události",
"Repeat" => "Opakovat",
"Advanced" => "Pokročilé",
"Select weekdays" => "Vybrat dny v týdnu",
"Select days" => "Vybrat dny",
"and the events day of year." => "a denní události v roce.",
"and the events day of month." => "a denní události v měsíci.",
"Select months" => "Vybrat měsíce",
"Select weeks" => "Vybrat týdny",
"and the events week of year." => "a týden s událostmi v roce.",
"Interval" => "Interval",
"End" => "Konec",
"occurrences" => "výskyty",
"create a new calendar" => "vytvořit nový kalendář",
"Import a calendar file" => "Importovat soubor kalendáře",
"Please choose a calendar" => "Vyberte, prosím, kalendář",
"Name of new calendar" => "Název nového kalendáře",
"Take an available name!" => "Použijte dostupný název.",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendář s tímto názvem již existuje. Pokud název použijete, budou tyto kalendáře sloučeny.",
"Remove all events from the selected calendar" => "Odebrat všechny události z vybraného kalendáře",
"Import" => "Importovat",
"Close Dialog" => "Zavřít dialog",
"Create a new event" => "Vytvořit novou událost",
"Share with:" => "Sdílet s:",
"Shared with" => "Sdíleno s",
"Unshare" => "Od-sdílet",
"Nobody" => "Nikdo",
"Shared via calendar" => "Sdíleno skrze kalendář",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "POZNÁMKA: Činnosti na událostech sdílených skrze kalendář budou mít vliv na sdílení celého kalendáře.",
"View an event" => "Zobrazit událost",
"No categories selected" => "Žádné kategorie nevybrány",
"of" => "z",
"at" => "v",
"General" => "Hlavní",
"Timezone" => "Časové pásmo",
"Update timezone automatically" => "Aktualizovat automaticky časové pásmo",
"Time format" => "Formát času",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Týden začíná v",
"Cache" => "Vyrovnávací paměť",
"Clear cache for repeating events" => "Vymazat paměť pro opakující se události",
"URLs" => "URL",
"Calendar CalDAV syncing addresses" => "Kalendář CalDAV synchronizuje adresy",
"more info" => "podrobnosti",
"Primary address (Kontact et al)" => "Primární adresa (veřejná)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Odkaz(y) kalendáře pouze pro čtení"
);
